@@ -8,7 +8,7 @@ use autodie qw(:all);
 no indirect ':fatal';
 
 use 5.010;
-use version ; our $VERSION = qv('1.0.3');
+use version ; our $VERSION = qv('1.0.0');
 
 use Carp;
 
@@ -18,7 +18,6 @@ use VSGDR::UnitTest::TestSet::Representation;
 use VSGDR::UnitTest::TestSet::Resx;
 
 use Getopt::Euclid qw( :vars<opt_> );
-use List::MoreUtils qw{firstidx} ;
 
 use Data::Dumper;
 use File::Basename;
@@ -28,54 +27,21 @@ my %ValidParserMakeArgs = ( vb  => "NET::VB"
                           , xls => "XLS"
                           , xml => "XML"
                           ) ;
-my %ValidParserMakeArgs2 = ( vb  => "NET2::VB"
-                           , cs  => "NET2::CS"
-                           ) ;                          
-                          
 my @validSuffixes       = map { '.'.$_ } keys %ValidParserMakeArgs ;
 
 
-my $version             = $opt_version ;
-
-
 my($infname, $indirectories, $insfx) = fileparse($opt_infile, @validSuffixes);
-croak 'Invalid input file'   unless defined $insfx ;            
 $insfx        = lc $insfx ;
 $insfx        = substr(lc $insfx,1) ;
 my($outfname, $outdirectories, $outsfx) = fileparse($opt_outfile, @validSuffixes);
-croak 'Invalid output file'   unless defined $outsfx ;            
 $outsfx       = lc $outsfx ;
 $outsfx       = substr(lc $outsfx,1) ;
     
-my %Parsers            = () ;
-$Parsers{${insfx}}     = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } );
-# if input is in a .net language, add in a .net2 parser to the list
-if ( firstidx { $_ eq ${insfx} } ['cs','vb']  != -1 ) {
-    $Parsers{"${insfx}2"}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${insfx}} } );
-}
-# if output is needed in ssdt unit test format  add in a .net2 parser to the list
-if ($version == 1)  {
-    $Parsers{${outsfx}}    = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${outsfx}} } );
-}
-else {
-    $Parsers{"${outsfx}2"} = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${outsfx}} } );
-}
-
-my $testSet         = undef ;
-eval {
-    $testSet         = $Parsers{$insfx}->deserialise($opt_infile);
-    } ;
-if ( not defined $testSet ) {
-    if ( exists $Parsers{"${insfx}2"}) {
-        eval {
-            $testSet     = $Parsers{"${insfx}2"}->deserialise($opt_infile);
-            }
-    }            
-    else {
-        croak 'Parsing failed.'; 
-    }
-}
+my %Parsers = () ;
+$Parsers{${insfx}}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } );
+$Parsers{${outsfx}} = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${outsfx}} } );
 
+my $testSet         = $Parsers{$insfx}->deserialise($opt_infile);
 
 my $resxname        = $infname . ".resx" ;
 my $o_resx          = VSGDR::UnitTest::TestSet::Resx->new() ;
@@ -98,13 +64,7 @@ foreach my $test ( @{ $testSet->tests() } ) {
     $testSet_clone->className($testSet->className() . '_' . $test->testName() ) ;
     $testSet_clone->tests([$test]) ;
     
-    if ($version == 1)  {
-        $Parsers{$outsfx}->serialise($outfname."_".$test->testName().".".$outsfx, $testSet_clone);
-    }
-    else {
-        $Parsers{"${outsfx}2"}->serialise($outfname."_".$test->testName().".".$outsfx, $testSet_clone);
-    }
-
+    $Parsers{$outsfx}->serialise($outfname."_".$test->testName().".".$outsfx, $testSet_clone);
     $o_resx_clone->serialise( ${outfname}."_".$test->testName().".resx", ${o_resx_clone} ); 
 
 }
@@ -132,7 +92,7 @@ creates a .vb file for each test in myTest.cs, each file name beginning with 'sp
 
 =head1 VERSION
 
-1.0.3
+1.0.0
 
 =head1 USAGE
 
@@ -152,6 +112,8 @@ Specify input file
     repeatable
 
 
+=back
+
 =item  -o[ut][file]    [=]<file>
 
 Specify output file
@@ -168,15 +130,6 @@ Specify output file
 
 =over
 
-=item  -v[er][sion] [=]<outputversion>
-
-Output version type
-
-=for Euclid:
-    outputversion.type:    /[12]/
-    outputversion.default:  1
-
-=back
 
 =head1 AUTHOR
 
